aboutsummaryrefslogtreecommitdiffstats
path: root/librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h b/librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h
index dd75db3..2ba9065 100644
--- a/librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h
+++ b/librifunktionsteckensnittsglyfrasteriseringsprogrambiblioteket.h
@@ -121,14 +121,14 @@ void rtgrpblib_draw_quadratic_bezier(RTGRPBLIB_RASTER *restrict raster,
* @param x3, y3 The second control point
* @param x4, y4 The end point
*/
-void rtgrpblib_draw_cubic_bezier(RTGRPBLIB_RASTER *restrict raster, /* needed for OpenType */
+void rtgrpblib_draw_cubic_bezier(RTGRPBLIB_RASTER *restrict raster,
double x1, double y1,
double x2, double y2,
double x3, double y3,
double x4, double y4);
/**
* Draw a circular arc
*
* @param raster The drawing buffer
* @param x0, y0 The midpoint of the ellipse
@@ -137,10 +137,10 @@ void rtgrpblib_draw_cubic_bezier(RTGRPBLIB_RASTER *restrict raster, /* needed fo
* @param start The angular starting point of the arc, in radians
* @param end The angular end point of the arc, in radians
*/
-void rtgrpblib_draw_circular_arc(RTGRPBLIB_RASTER *restrict raster, /* needed for outline stoking */
- double x0, double y0,
- double semiwidth, double semiheight,
- double start, double end);
+void rtgrpblib_draw_elliptical_arc(RTGRPBLIB_RASTER *restrict raster,
+ double x0, double y0,
+ double semiwidth, double semiheight,
+ double start, double end);
#if defined(__clang__)
@@ -121,14 +121,14 @@ void rtgrpblib_draw_quadratic_bezier(RTGRPBLIB_RASTER *restrict raster,
double x4, double y4);
/**
- * Draw a circular arc
+ * Draw a elliptical arc
*
* @param raster The drawing buffer